# Tutorial - **More** NER Statistics

Now that we have a Corpus loaded, let's investigate the rest of the `recon.stats` module.
The best way to use the `recon.stats` module is through Prodigy directly.

Recon comes packaged with sidecar Prodigy Recipes for core NER annotation workflows.


Full Prodigy recipe map


* `ner.manual` => `recon.ner_manual`
* `ner.manual` => `recon.ner_correct`
